==> free-1.4.tar.gz: FREE-1.4/FreeClient/FCFrame4.java <==
/*
 * FREE 2000
 *
 * Copyright (c) Jason Kitcat, University of Warwick
 *
 * jeep@thecouch.org   http://www.thecouch.org/free/
 *
 * Knoll Cottage, Sutton Place, Nr.Abinger, Dorking, Surrey RH5 6RN United Kingdom
 *
 * Tel: 07956 886 508  Fax: 0870 052 7114
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program (gpl.txt); if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
 
package FreeClient;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.text.*;

/**
 * Screen to show progress of voter authentication.
 *
 * @version 0.4 31 March 2000
 * @author Jason Kitcat
 */
public class FCFrame4 extends JFrame 
{

	protected static boolean status;

	javax.swing.JTextPane jTextPane1 = new javax.swing.JTextPane();
	javax.swing.JButton jButton1 = new javax.swing.JButton();
	javax.swing.JButton jButton2 = new javax.swing.JButton();

	protected FCFrame4() {
	
		jTextPane1.setVisible(true);
		jTextPane1.setSize(new java.awt.Dimension(330, 190));
		
		JPanel jPanel1 = new JPanel();
		jPanel1.setLayout(new BoxLayout(jPanel1, BoxLayout.Y_AXIS));
		jPanel1.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
		jPanel1.add(jTextPane1);
		
		jButton1.setText("OK");
		jButton1.setVisible(false);
		jButton1.setToolTipText("click to continue");
		jButton1.setPreferredSize(new java.awt.Dimension(70, 20));
		jButton1.setMinimumSize(new java.awt.Dimension(70, 20));

		jButton2.setText("Quit");
		jButton2.setVisible(false);
		jButton2.setToolTipText("click to quit");
		jButton2.setPreferredSize(new java.awt.Dimension(70, 20));
		jButton2.setMinimumSize(new java.awt.Dimension(70, 20));

		JPanel buttonPane = new JPanel();
		buttonPane.setLayout(new BoxLayout(buttonPane, BoxLayout.X_AXIS));
		buttonPane.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
		buttonPane.add(Box.createHorizontalGlue());
		buttonPane.add(jButton2);
		buttonPane.add(Box.createRigidArea(new Dimension(10,0)));
		buttonPane.add(jButton1);

		setLocation(new java.awt.Point(40, 40));
		setTitle("FREE Authorisation");
		setSize(new java.awt.Dimension(350, 300));
		Container contentPane = getContentPane();
		contentPane.add(jPanel1, BorderLayout.CENTER);
		contentPane.add(buttonPane, BorderLayout.SOUTH);
	
	}

	protected void initComponents() throws Exception
	{

		jButton1.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent e) {
				jButton1ActionPerformed(e);
			}
		});
		jButton2.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent e) {
				jButton2ActionPerformed(e);
			}
		});
		addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing(java.awt.event.WindowEvent e) {
				thisWindowClosing(e);
			}
		});
	}

	// Show an informational message (black, plain text)
	protected void showInfo(String msg) {
		SimpleAttributeSet attrs = new SimpleAttributeSet();
		StyleConstants.setForeground(attrs, Color.black);
		showMsg(msg, attrs);
	}
  
	// Show an warning message (red, bold text)
	protected void showError(String msg) {
		SimpleAttributeSet attrs = new SimpleAttributeSet();
		StyleConstants.setForeground(attrs, Color.red);
		StyleConstants.setBold(attrs, true);
		showMsg(msg, attrs);
	}
	
	// Show a text message using the specified AttributeSet
	protected void showMsg(String msg, AttributeSet attrs) {
		Document doc = jTextPane1.getDocument();
		msg += "\n";
		try {
			doc.insertString(doc.getLength(), msg, attrs);
		} catch (BadLocationException ex) {
			ex.printStackTrace();
		}
	}
  
  	private boolean mShown = false;
  	
	public void addNotify() 
	{
		super.addNotify();
		
		if (mShown)
			return;
			
		// resize frame to account for menubar
		JMenuBar jMenuBar = getJMenuBar();
		if (jMenuBar != null) {
			int jMenuBarHeight = jMenuBar.getPreferredSize().height;
			Dimension dimension = getSize();
			dimension.height += jMenuBarHeight;
			setSize(dimension);
		}

		mShown = true;
	}

	// Close the window when the close box is clicked
	void thisWindowClosing(java.awt.event.WindowEvent e)
	{
	}
	
	protected void jButton2ActionPerformed(java.awt.event.ActionEvent e) {
	
		FClient.frame3.cleanUp();
		setVisible(false);
		dispose();
		System.exit(0);
		
	}
	
	protected void jButton1ActionPerformed(java.awt.event.ActionEvent e) {
	
		if (status == true) {
			setVisible(false);
			FClient.frame3.cleanUp();
			FClient.ercheck = false;
			FClient.frame.setVisible(true);
			dispose();
		} else {
			setVisible(false);
			FClient.frame4.jButton1.setVisible(false);
			FClient.frame4.jButton2.setVisible(false);
			FClient.frame3.setVisible(true);
		}			
	
	}
	
	
	
}

==> free-1.5.tar.gz: FREE-1.5/FreeClient/FCFrame4.java <==
/*
 * GNU.FREE 2001
 *
 * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
 *
 * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
 *
 * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
 * 
 * FREE e-democracy site: http://www.thecouch.org/free/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program (gpl.txt); if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
 
package FreeClient;

import java.awt.*;
import java.awt.event.*;

import Free.awt.*;

/**
 * Screen to show progress of voter authentication.
 *
 * @version 0.5 26 February 2001
 * @author Jason Kitcat, Rajagopal C.V
 */
public class FCFrame4 extends Frame 
{

	protected static boolean status;

	TextArea jTextPane1 = new TextArea();
	Button jButton1 = new Button();
	Button jButton2 = new Button();

	protected FCFrame4() {
	
		jButton1.setLabel("OK");
		jButton2.setLabel("Quit");
		setTitle("FREE Authorisation");

		FreePanel scrollPanel = new FreePanel(" ");
		scrollPanel.setInsets(3, 3, 3, 3);
		
		scrollPanel.addComponent( 0, 0, 1, 2, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 1.0f, jTextPane1);
		scrollPanel.addComponent( 2, 0, 1, 1, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 0.0f, jButton1);
		scrollPanel.addComponent( 2, 1, 1, 1, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 0.0f, jButton2);
			
		add(scrollPanel, BorderLayout.CENTER);
		setSize(new java.awt.Dimension(350, 300));
	
	}

	protected void initComponents() throws Exception
	{

		jButton1.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent e) {
				jButton1ActionPerformed(e);
			}
		});
		jButton2.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent e) {
				jButton2ActionPerformed(e);
			}
		});
		addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing(java.awt.event.WindowEvent e) {
				thisWindowClosing(e);
			}
		});
		
		jButton1.setEnabled(false);
		jButton2.setEnabled(false);
	}

	// Show an informational message (black, plain text)
	protected void showInfo(String msg) {
		showMsg(msg);
	}
  
	// Show an warning message (red, bold text)
	protected void showError(String msg) {
		showMsg(msg);
	}
	
	// Show a text message using the specified AttributeSet
	protected void showMsg(String msg) {
		msg += "\n";
		jTextPane1.setText(jTextPane1.getText() + msg);
	}
	

	// Close the window when the close box is clicked
	void thisWindowClosing(java.awt.event.WindowEvent e)
	{
	}
	
	protected void jButton2ActionPerformed(java.awt.event.ActionEvent e) {
	
		FClient.frame3.cleanUp();
		setVisible(false);
		dispose();
		System.exit(0);
		
	}
	
	protected void jButton1ActionPerformed(java.awt.event.ActionEvent e) {
	
		if (status == true) {
			setVisible(false);
			FClient.frame3.cleanUp();
			FClient.ercheck = false;
			FClient.frame.setVisible(true);
			dispose();
		} else {
			setVisible(false);
			FClient.frame4.jButton1.setEnabled(false);
			FClient.frame4.jButton2.setEnabled(false);
			FClient.frame3.setVisible(true);
		}			
	
	}
	
	
	
}
